from . import simulationio

def export3d_solid_mesh(data_container_array, meshing_package = None, output_path = None, package_location = None, surface_mesh_face_labels_array_path = None, feature_phases_array_path = None, feature_euler_angles_array_path = None, feature_centroid_array_path = None, refine_mesh = None, max_radius_edge_ratio = None, min_dihedral_angle = None, limit_tetrahedra_volume = None, max_tetrahedra_volume = None, optimization_level = None, include_holes_using_phase_id = None, phase_id = None, tet_data_container_name = None, vertex_attribute_matrix_name = None, cell_attribute_matrix_name = None, gmsh_stl_file_name = None, mesh_file_format = None, netgen_stl_file_name = None, mesh_size = None, observer = None) -> int:
  """
  Export3dSolidMesh

  :param data_container_array | DataContainerArray
  :param meshing_package | int MeshingPackage
  :param output_path | QString outputPath
  :param package_location | QString PackageLocation
  :param surface_mesh_face_labels_array_path | DataArrayPath SurfaceMeshFaceLabelsArrayPath
  :param feature_phases_array_path | DataArrayPath FeaturePhasesArrayPath
  :param feature_euler_angles_array_path | DataArrayPath FeatureEulerAnglesArrayPath
  :param feature_centroid_array_path | DataArrayPath FeatureCentroidArrayPath
  :param refine_mesh | bool RefineMesh
  :param max_radius_edge_ratio | float MaxRadiusEdgeRatio
  :param min_dihedral_angle | float MinDihedralAngle
  :param limit_tetrahedra_volume | bool LimitTetrahedraVolume
  :param max_tetrahedra_volume | float MaxTetrahedraVolume
  :param optimization_level | int OptimizationLevel
  :param include_holes_using_phase_id | bool IncludeHolesUsingPhaseID
  :param phase_id | int PhaseID
  :param tet_data_container_name | QString TetDataContainerName
  :param vertex_attribute_matrix_name | QString VertexAttributeMatrixName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param gmsh_stl_file_name | QString GmshSTLFileName
  :param mesh_file_format | int MeshFileFormat
  :param netgen_stl_file_name | QString NetgenSTLFileName
  :param mesh_size | int MeshSize
  :param observer | Observer
  """

  filter = simulationio.Export3dSolidMesh()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if meshing_package is not None:
    filter.MeshingPackage = meshing_package
  if output_path is not None:
    filter.outputPath = output_path
  if package_location is not None:
    filter.PackageLocation = package_location
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  if feature_centroid_array_path is not None:
    filter.FeatureCentroidArrayPath = feature_centroid_array_path
  if refine_mesh is not None:
    filter.RefineMesh = refine_mesh
  if max_radius_edge_ratio is not None:
    filter.MaxRadiusEdgeRatio = max_radius_edge_ratio
  if min_dihedral_angle is not None:
    filter.MinDihedralAngle = min_dihedral_angle
  if limit_tetrahedra_volume is not None:
    filter.LimitTetrahedraVolume = limit_tetrahedra_volume
  if max_tetrahedra_volume is not None:
    filter.MaxTetrahedraVolume = max_tetrahedra_volume
  if optimization_level is not None:
    filter.OptimizationLevel = optimization_level
  if include_holes_using_phase_id is not None:
    filter.IncludeHolesUsingPhaseID = include_holes_using_phase_id
  if phase_id is not None:
    filter.PhaseID = phase_id
  if tet_data_container_name is not None:
    filter.TetDataContainerName = tet_data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if gmsh_stl_file_name is not None:
    filter.GmshSTLFileName = gmsh_stl_file_name
  if mesh_file_format is not None:
    filter.MeshFileFormat = mesh_file_format
  if netgen_stl_file_name is not None:
    filter.NetgenSTLFileName = netgen_stl_file_name
  if mesh_size is not None:
    filter.MeshSize = mesh_size
  filter.execute()
  return filter.ErrorCode

def import_fea_data(data_container_array, fea_package = None, odb_name = None, odb_file_path = None, abq_python_command = None, instance_name = None, step = None, frame_number = None, bsam_input_file = None, deform_input_file = None, deform_point_track_input_file = None, time_series_bundle_name = None, import_single_time_step = None, single_time_step_value = None, selected_time_array_name = None, selected_time_step_array_name = None, selected_point_num_array_name = None, selected_x_coord_array_name = None, selected_y_coord_array_name = None, data_array_list = None, data_container_name = None, vertex_attribute_matrix_name = None, cell_attribute_matrix_name = None, observer = None) -> int:
  """
  ImportFEAData

  :param data_container_array | DataContainerArray
  :param fea_package | int FEAPackage
  :param odb_name | QString odbName
  :param odb_file_path | QString odbFilePath
  :param abq_python_command | QString ABQPythonCommand
  :param instance_name | QString InstanceName
  :param step | QString Step
  :param frame_number | int FrameNumber
  :param bsam_input_file | QString BSAMInputFile
  :param deform_input_file | QString DEFORMInputFile
  :param deform_point_track_input_file | QString DEFORMPointTrackInputFile
  :param time_series_bundle_name | QString TimeSeriesBundleName
  :param import_single_time_step | bool ImportSingleTimeStep
  :param single_time_step_value | int SingleTimeStepValue
  :param selected_time_array_name | QString SelectedTimeArrayName
  :param selected_time_step_array_name | QString SelectedTimeStepArrayName
  :param selected_point_num_array_name | QString SelectedPointNumArrayName
  :param selected_x_coord_array_name | QString SelectedXCoordArrayName
  :param selected_y_coord_array_name | QString SelectedYCoordArrayName
  :param data_array_list | QStringList DataArrayList
  :param data_container_name | QString DataContainerName
  :param vertex_attribute_matrix_name | QString VertexAttributeMatrixName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param observer | Observer
  """

  filter = simulationio.ImportFEAData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if fea_package is not None:
    filter.FEAPackage = fea_package
  if odb_name is not None:
    filter.odbName = odb_name
  if odb_file_path is not None:
    filter.odbFilePath = odb_file_path
  if abq_python_command is not None:
    filter.ABQPythonCommand = abq_python_command
  if instance_name is not None:
    filter.InstanceName = instance_name
  if step is not None:
    filter.Step = step
  if frame_number is not None:
    filter.FrameNumber = frame_number
  if bsam_input_file is not None:
    filter.BSAMInputFile = bsam_input_file
  if deform_input_file is not None:
    filter.DEFORMInputFile = deform_input_file
  if deform_point_track_input_file is not None:
    filter.DEFORMPointTrackInputFile = deform_point_track_input_file
  if time_series_bundle_name is not None:
    filter.TimeSeriesBundleName = time_series_bundle_name
  if import_single_time_step is not None:
    filter.ImportSingleTimeStep = import_single_time_step
  if single_time_step_value is not None:
    filter.SingleTimeStepValue = single_time_step_value
  if selected_time_array_name is not None:
    filter.SelectedTimeArrayName = selected_time_array_name
  if selected_time_step_array_name is not None:
    filter.SelectedTimeStepArrayName = selected_time_step_array_name
  if selected_point_num_array_name is not None:
    filter.SelectedPointNumArrayName = selected_point_num_array_name
  if selected_x_coord_array_name is not None:
    filter.SelectedXCoordArrayName = selected_x_coord_array_name
  if selected_y_coord_array_name is not None:
    filter.SelectedYCoordArrayName = selected_y_coord_array_name
  if data_array_list is not None:
    filter.DataArrayList = data_array_list
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  filter.execute()
  return filter.ErrorCode

def export_lammps_file(data_container_array, lammps_file = None, atom_feature_labels_path = None, observer = None) -> int:
  """
  ExportLAMMPSFile

  :param data_container_array | DataContainerArray
  :param lammps_file | QString LammpsFile
  :param atom_feature_labels_path | DataArrayPath AtomFeatureLabelsPath
  :param observer | Observer
  """

  filter = simulationio.ExportLAMMPSFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if lammps_file is not None:
    filter.LammpsFile = lammps_file
  if atom_feature_labels_path is not None:
    filter.AtomFeatureLabelsPath = atom_feature_labels_path
  filter.execute()
  return filter.ErrorCode

def export_damask_files(data_container_array, data_format = None, output_path = None, geometry_file_name = None, homogenization_index = None, feature_ids_array_path = None, cell_phases_array_path = None, cell_euler_angles_array_path = None, compress_geom_file = None, observer = None) -> int:
  """
  ExportDAMASKFiles

  :param data_container_array | DataContainerArray
  :param data_format | int DataFormat
  :param output_path | QString OutputPath
  :param geometry_file_name | QString GeometryFileName
  :param homogenization_index | int HomogenizationIndex
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param cell_euler_angles_array_path | DataArrayPath CellEulerAnglesArrayPath
  :param compress_geom_file | bool CompressGeomFile
  :param observer | Observer
  """

  filter = simulationio.ExportDAMASKFiles()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_format is not None:
    filter.DataFormat = data_format
  if output_path is not None:
    filter.OutputPath = output_path
  if geometry_file_name is not None:
    filter.GeometryFileName = geometry_file_name
  if homogenization_index is not None:
    filter.HomogenizationIndex = homogenization_index
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  if compress_geom_file is not None:
    filter.CompressGeomFile = compress_geom_file
  filter.execute()
  return filter.ErrorCode

def export_on_scale_table_file(data_container_array, output_path = None, output_file_prefix = None, pzflex_feature_ids_array_path = None, num_keypoints = None, phase_names_array_path = None, observer = None) -> int:
  """
  ExportOnScaleTableFile

  :param data_container_array | DataContainerArray
  :param output_path | QString OutputPath
  :param output_file_prefix | QString OutputFilePrefix
  :param pzflex_feature_ids_array_path | DataArrayPath PzflexFeatureIdsArrayPath
  :param num_keypoints | IntVec3Type NumKeypoints
  :param phase_names_array_path | DataArrayPath PhaseNamesArrayPath
  :param observer | Observer
  """

  filter = simulationio.ExportOnScaleTableFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if output_file_prefix is not None:
    filter.OutputFilePrefix = output_file_prefix
  if pzflex_feature_ids_array_path is not None:
    filter.PzflexFeatureIdsArrayPath = pzflex_feature_ids_array_path
  if num_keypoints is not None:
    filter.NumKeypoints = num_keypoints
  if phase_names_array_path is not None:
    filter.PhaseNamesArrayPath = phase_names_array_path
  filter.execute()
  return filter.ErrorCode

def create_abaqus_file(data_container_array, output_path = None, output_file_prefix = None, job_name = None, num_depvar = None, num_user_out_var = None, mat_const = None, abq_feature_ids_array_path = None, cell_euler_angles_array_path = None, cell_phases_array_path = None, observer = None) -> int:
  """
  CreateAbaqusFile

  :param data_container_array | DataContainerArray
  :param output_path | QString OutputPath
  :param output_file_prefix | QString OutputFilePrefix
  :param job_name | QString JobName
  :param num_depvar | int NumDepvar
  :param num_user_out_var | int NumUserOutVar
  :param mat_const | DynamicTableData MatConst
  :param abq_feature_ids_array_path | DataArrayPath AbqFeatureIdsArrayPath
  :param cell_euler_angles_array_path | DataArrayPath CellEulerAnglesArrayPath
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param observer | Observer
  """

  filter = simulationio.CreateAbaqusFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if output_file_prefix is not None:
    filter.OutputFilePrefix = output_file_prefix
  if job_name is not None:
    filter.JobName = job_name
  if num_depvar is not None:
    filter.NumDepvar = num_depvar
  if num_user_out_var is not None:
    filter.NumUserOutVar = num_user_out_var
  if mat_const is not None:
    filter.MatConst = mat_const
  if abq_feature_ids_array_path is not None:
    filter.AbqFeatureIdsArrayPath = abq_feature_ids_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  filter.execute()
  return filter.ErrorCode

def create_bsam_file(data_container_array, output_path = None, output_file_prefix = None, num_clusters = None, observer = None) -> int:
  """
  CreateBsamFile

  :param data_container_array | DataContainerArray
  :param output_path | QString OutputPath
  :param output_file_prefix | QString OutputFilePrefix
  :param num_clusters | int NumClusters
  :param observer | Observer
  """

  filter = simulationio.CreateBsamFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if output_file_prefix is not None:
    filter.OutputFilePrefix = output_file_prefix
  if num_clusters is not None:
    filter.NumClusters = num_clusters
  filter.execute()
  return filter.ErrorCode

def export_multi_on_scale_table_file(data_container_array, output_path = None, data_container_prefix = None, matrix_name = None, array_name = None, selected_arrays = None, num_keypoints = None, phase_names_array_path = None, observer = None) -> int:
  """
  ExportMultiOnScaleTableFile

  :param data_container_array | DataContainerArray
  :param output_path | QString OutputPath
  :param data_container_prefix | QString DataContainerPrefix
  :param matrix_name | QString MatrixName
  :param array_name | QString ArrayName
  :param selected_arrays | QString SelectedArrays
  :param num_keypoints | IntVec3Type NumKeypoints
  :param phase_names_array_path | DataArrayPath PhaseNamesArrayPath
  :param observer | Observer
  """

  filter = simulationio.ExportMultiOnScaleTableFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_path is not None:
    filter.OutputPath = output_path
  if data_container_prefix is not None:
    filter.DataContainerPrefix = data_container_prefix
  if matrix_name is not None:
    filter.MatrixName = matrix_name
  if array_name is not None:
    filter.ArrayName = array_name
  if selected_arrays is not None:
    filter.SelectedArrays = selected_arrays
  if num_keypoints is not None:
    filter.NumKeypoints = num_keypoints
  if phase_names_array_path is not None:
    filter.PhaseNamesArrayPath = phase_names_array_path
  filter.execute()
  return filter.ErrorCode

def import_on_scale_table_file(data_container_array, volume_data_container_name = None, cell_attribute_matrix_name = None, phase_attribute_matrix_name = None, material_name_array_name = None, rect_grid_geometry_desc = None, input_file = None, origin = None, spacing = None, feature_ids_array_name = None, observer = None) -> int:
  """
  ImportOnScaleTableFile

  :param data_container_array | DataContainerArray
  :param volume_data_container_name | DataArrayPath VolumeDataContainerName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param phase_attribute_matrix_name | QString PhaseAttributeMatrixName
  :param material_name_array_name | QString MaterialNameArrayName
  :param rect_grid_geometry_desc | QString RectGridGeometryDesc
  :param input_file | QString InputFile
  :param origin | FloatVec3Type Origin
  :param spacing | FloatVec3Type Spacing
  :param feature_ids_array_name | QString FeatureIdsArrayName
  :param observer | Observer
  """

  filter = simulationio.ImportOnScaleTableFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if volume_data_container_name is not None:
    filter.VolumeDataContainerName = volume_data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if phase_attribute_matrix_name is not None:
    filter.PhaseAttributeMatrixName = phase_attribute_matrix_name
  if material_name_array_name is not None:
    filter.MaterialNameArrayName = material_name_array_name
  if rect_grid_geometry_desc is not None:
    filter.RectGridGeometryDesc = rect_grid_geometry_desc
  if input_file is not None:
    filter.InputFile = input_file
  if origin is not None:
    filter.Origin = origin
  if spacing is not None:
    filter.Spacing = spacing
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

def import_delam_data(data_container_array, csdgm_file = None, bvid_std_out_file = None, interface_thickness = None, data_container_path = None, observer = None) -> int:
  """
  ImportDelamData

  :param data_container_array | DataContainerArray
  :param csdgm_file | QString CSDGMFile
  :param bvid_std_out_file | QString BvidStdOutFile
  :param interface_thickness | float InterfaceThickness
  :param data_container_path | DataArrayPath DataContainerPath
  :param observer | Observer
  """

  filter = simulationio.ImportDelamData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if csdgm_file is not None:
    filter.CSDGMFile = csdgm_file
  if bvid_std_out_file is not None:
    filter.BvidStdOutFile = bvid_std_out_file
  if interface_thickness is not None:
    filter.InterfaceThickness = interface_thickness
  if data_container_path is not None:
    filter.DataContainerPath = data_container_path
  filter.execute()
  return filter.ErrorCode

